# driver

```
usage: driver [-h] path

Get group or dataset driver

positional arguments:
  path        Path to group or dataset

optional arguments:
  -h, --help  show this help message and exit
```
